@@ -86,8 +86,15 @@ NULL
 
 #' @export
 #' @rdname output-expectations
-expect_output <- function(object, regexp = NULL, ..., info = NULL, label = NULL) {
-  act <- quasi_capture(enquo(object), capture_output, label = label)
+#' @inheritParams capture_output
+expect_output <- function(object,
+                          regexp = NULL,
+                          ...,
+                          info = NULL,
+                          label = NULL,
+                          width = 80
+                          ) {
+  act <- quasi_capture(enquo(object), label, capture_output, width = width)
 
   if (identical(regexp, NA)) {
     expect(
@@ -116,12 +123,24 @@ expect_error <- function(object,
                          class = NULL,
                          ...,
                          info = NULL,
-                         label = NULL) {
-  act <- quasi_capture(enquo(object), capture_error, label = label)
+                         label = NULL
+                         ) {
+
+  act <- quasi_capture(enquo(object), label, capture_error)
   msg <- compare_condition(act$cap, act$lab, regexp = regexp, class = class, ...)
   expect(is.null(msg), msg, info = info)
 
-  invisible(act$val %||% act$err)
+  if (!is.null(act$cap)) {
+    if (!simple_error(act$cap) && is.null(class) && !is.null(regexp)) {
+      klass <- paste0(class(act$cap), collapse = "/")
+      warn(paste0(
+        act$lab, " generated a condition with class ", klass, ".\n",
+        "It is less fragile to test custom conditions with `class`"
+      ))
+    }
+  }
+
+  invisible(act$val %||% act$cap)
 }
 
 #' @export
@@ -131,23 +150,29 @@ expect_condition <- function(object,
                              class = NULL,
                              ...,
                              info = NULL,
-                             label = NULL) {
-  act <- quasi_capture(enquo(object), capture_condition, label = label)
+                             label = NULL
+                             ) {
+  act <- quasi_capture(enquo(object), label, capture_condition)
   msg <- compare_condition(
     act$cap, act$lab, regexp = regexp, class = class, ...,
     cond_type = "condition"
   )
   expect(is.null(msg), msg, info = info)
 
-  invisible(act$val %||% act$err)
+  invisible(act$val %||% act$cap)
 }
 
 
 #' @export
 #' @rdname output-expectations
-expect_message <- function(object, regexp = NULL, ..., all = FALSE,
-                           info = NULL, label = NULL) {
-  act <- quasi_capture(enquo(object), capture_messages, label = label)
+expect_message <- function(object,
+                           regexp = NULL,
+                           ...,
+                           all = FALSE,
+                           info = NULL,
+                           label = NULL
+                           ) {
+  act <- quasi_capture(enquo(object), label, capture_messages)
   msg <- compare_messages(act$cap, act$lab, regexp = regexp, all = all, ...)
   expect(is.null(msg), msg, info = info)
 
@@ -156,9 +181,14 @@ expect_message <- function(object, regexp = NULL, ..., all = FALSE,
 
 #' @export
 #' @rdname output-expectations
-expect_warning <- function(object, regexp = NULL, ..., all = FALSE,
-                           info = NULL, label = NULL) {
-  act <- quasi_capture(enquo(object), capture_warnings, label = label)
+expect_warning <- function(object,
+                           regexp = NULL,
+                           ...,
+                           all = FALSE,
+                           info = NULL,
+                           label = NULL
+                           ) {
+  act <- quasi_capture(enquo(object), label, capture_warnings)
   msg <- compare_messages(
     act$cap, act$lab, regexp = regexp, all = all, ...,
     cond_type = "warnings"
@@ -171,7 +201,7 @@ expect_warning <- function(object, regexp = NULL, ..., all = FALSE,
 #' @export
 #' @rdname output-expectations
 expect_silent <- function(object) {
-  act <- quasi_capture(enquo(object), evaluate_promise)
+  act <- quasi_capture(enquo(object), NULL, evaluate_promise)
 
   outputs <- c(
     if (!identical(act$cap$output, "")) "output",
@@ -250,6 +280,21 @@ compare_condition <- function(cond, lab, regexp = NULL, class = NULL, ...,
   )
 }
 
+simple_error <- function(x) {
+  if (!inherits(x, "error")) {
+    return(FALSE)
+  }
+
+  if (inherits(x, "simpleError")) {
+    return(TRUE)
+  }
+
+  if (inherits(x, "Rcpp::exception")) {
+    return(TRUE)
+  }
+
+  inherits_only(x, c("rlang_error", "error", "condition"))
+}
 
 compare_messages <- function(messages,
                              lab,
